@@ -11,7 +11,6 @@ import justpy as jp
 import os
 import sys
 import psutil
-import socket
 import traceback
 from jpcore.demostarter import Demostarter
 from jpcore.tutorial import TutorialManager,Example
@@ -435,25 +434,29 @@ class DemoBrowser(BaseWebPage):
             except Exception as ex:
                 self.handleException(ex)
         
-    def mount(self,demo,index:int):
+    def mount(self,demo,index:int,force:bool=False):
         """
         mount the given demo 
         
         Args:
             demo(JustpyDemoApp): the demo to mount
             index(int): the index to mount the demo at
+            force(bool): if True force the mount even if there is an issue for this demo
         """
-        try:
-            total=len(self.demo_starter.demos)
-            print (f"mounting {index}/{total}:{demo}")
-            demo.mount(jp.app)
-            demo.try_it_url=f"/{demo.wpfunc.__name__}"
-            demo.status="✅"
-            self.mounted[demo.name]=demo
-            self.progress.text = f"mounting {index}/{total}"
-        except BaseException as ex:
-            demo.status=self.get_html_error(ex)
-              
+        if(force or demo.issue is None or demo.fixed is not None):
+            try:
+                total=len(self.demo_starter.demos)
+                print (f"mounting {index}/{total}:{demo}")
+                demo.mount(jp.app)
+                demo.try_it_url=f"/{demo.wpfunc.__name__}"
+                demo.status="✅"
+                self.mounted[demo.name]=demo
+                self.progress.text = f"mounting {index}/{total}"
+            except BaseException as ex:
+                demo.status=self.get_html_error(ex)
+        else:
+            demo.status=(f"can't mount due to unfixed issue {demo.issue}")
+            
     async def on_mount_all_btn_click(self,_msg):
         """
         mount all button has been clicked
