@@ -10,10 +10,10 @@ import traceback
 from argparse import ArgumentParser
 from argparse import RawDescriptionHelpFormatter
 from examples.basedemo import Demo
+from jpcore.example import ExampleManager
 from jpcore.demoapp import JustpyDemoApp
-from jpcore.utilities import find_files
 
-class Demostarter:
+class Demostarter(ExampleManager):
     """
     start justpy demos on different ports
     """
@@ -24,28 +24,20 @@ class Demostarter:
 
         Args:
             base_path(str): the base_path
+            mode(str): the mode of the demo starter
             debug(bool): if True switch on debug mode
         """
+        super().__init__(base_path=base_path,debug=debug)
         Demo.testmode = True
-        self.debug = debug
         self.mode = mode
-        self.script_dir = os.path.dirname(__file__)
-        if base_path is None:
-            base_path=os.path.dirname(self.script_dir)
-        if base_path.endswith("/examples"):
-            base_path=os.path.dirname(base_path)
-        self.justpy_dir = f"{base_path}/examples"
-        self.example_json_file=f"{self.justpy_dir}/examples.json"
-        if self.debug:
-            print(f"collecting examples from {self.justpy_dir}")
-        pymodule_files = find_files(self.justpy_dir, ".py")
+        
         self.demos = []
         self.demos_by_name={}
         self.demos_by_source_file={}
         self.servers = {}
         self.errors = {}
-        for pymodule_file in pymodule_files:
-            demo = JustpyDemoApp(examples_dir=self.justpy_dir,pymodule_file=pymodule_file,debug=debug)
+        for pymodule_file in self.pymodule_files:
+            demo = JustpyDemoApp(examples_dir=self.examples_dir,pymodule_file=pymodule_file,debug=debug)
             if demo.is_demo:
                 self.demos.append(demo)
                 self.demos_by_name[demo.name]=demo
@@ -62,6 +54,7 @@ class Demostarter:
         add video links to the demos
         """
         with open(self.example_json_file) as json_file:
+            # read in the example_json file
             example_json = json.load(json_file)
         if "examples" in example_json:
             for i, video_record in enumerate(example_json["examples"]):
@@ -70,10 +63,11 @@ class Demostarter:
                 if name and video_url:
                     if name in self.demos_by_source_file:
                         demo=self.demos_by_source_file[name]
-                        demo.video_url=video_url
                     elif name in self.demos_by_name:
                         demo=self.demos_by_name[name]
-                        demo.video_url=video_url
+                    demo.video_url=video_url
+                    demo.issue=video_record.get("issue",None)
+                    demo.fixed=video_record.get("fixed",None)
                 else:
                     raise Exception(f"name or url missing for example #{i}")
             
